<?php
/**
 * Skrill Core Email
 *
 * The Class for Process Skrill Payment Gateways
 * Copyright (c) Skrill
 *
 * @class   SkrillEmail
 * @package Skrill/Classes
 * @located at /core
 */
class SkrillEmailOxidSix extends \OxidEsales\EshopCommunity\Core\Email
{
    /**
     * @var null|oxConfig
     */
    protected static $oConfig = null;

    /**
     * Send email when do refund at backend.
     *
     * @param  integer $oxorderid ox order id
     * @param  string $newStatus new status
     * @return boolean
     */
    public static function sendNewOrderStatusEmail($oxorderid, $newStatus)
    {
        $oxEMail = oxNew('oxemail');
        $myConfig = self::_getConfig();
        $oViewConf = $myConfig->getActiveView()->getViewConfig();

        $oOrder = SkrillCore::getOrderById($oxorderid);
        $orderId = $oOrder->oxorder__oxordernr->value;

        $iOrderLang = (int) (isset($oOrder->oxorder__oxlang->value) ? $oOrder->oxorder__oxlang->value : 0);

        $oShop = self::getShopLanguage($iOrderLang);
        self::setMailParameters($oShop);

        $oLang = oxRegistry::getLang();

        $iOldTplLang = $oLang->getTplLanguage();
        $iOldBaseLang = $oLang->getTplLanguage();
        $oLang->setTplLanguage($iOrderLang);
        $oLang->setBaseLanguage($iOrderLang);

        $sFullName = $oOrder->oxorder__oxbillfname->getRawValue() . " " . $oOrder->oxorder__oxbilllname->getRawValue();

        // create messages
        $oSmarty = $oxEMail->_getSmarty();
        $oxEMail->setViewData("orderID", $orderId);
        $oxEMail->setViewData("order", $oOrder);
        $oxEMail->setViewData("oViewConf", $oViewConf);

        switch ($newStatus) {
            case SkrillCore::PENDINGSTATUS:
                $status = 'GENERAL_TEXT_PENDING';
                break;
            case SkrillCore::PROCESSEDSTATUS:
                $status = 'GENERAL_TEXT_PROCESSED';
                break;
            case SkrillCore::REFUNDEDSTATUS:
                $status = 'GENERAL_TEXT_REFUNDED';
                break;
            default:
                $status = '';
                break;
        }

        $oxEMail->setViewData("status", $status);

        // Process view data array through oxOutput processor
        $oxEMail->_processViewArray();

        $myConfig->setAdminMode(false);
        $oxEMail->setBody($oSmarty->fetch('new_status_order.tpl'));
        $oxEMail->setAltBody($oSmarty->fetch('new_status_order_plain.tpl'));
        $myConfig->setAdminMode(true);

        $sSubject = self::setSubjectLocale($status, $orderId, $oShop);

        $oLang->setTplLanguage($iOldTplLang);
        $oLang->setBaseLanguage($iOldBaseLang);

        $oxEMail->setSubject($sSubject);

        $oxEMail->setRecipient($oOrder->oxorder__oxbillemail->value, $sFullName);
        $oxEMail->setReplyTo($oShop->oxshops__oxorderemail->value, $oShop->oxshops__oxname->getRawValue());

        $blSuccess = $oxEMail->send();

        return $blSuccess;
    }

    /**
     * @return oxConfig
     */
    protected static function _getConfig()
    {
        if (self::$oConfig === null) {
            self::$oConfig = oxRegistry::getConfig();
        }

        return self::$oConfig;
    }

    /**
     * Set mail From, FromName, SMTP values
     *
     * @param oxShop $oShop Shop object
     */
    public static function setMailParameters($oShop)
    {
        self::clearMailer();

        $oxEMail = oxNew('oxemail');
        $oxEMail->setFrom($oShop->oxshops__oxorderemail->value, $oShop->oxshops__oxname->getRawValue());
        $oxEMail->setSmtp($oShop);
    }

    /**
     * Clears mailer settings (AllRecipients, ReplyTos, Attachments, Errors)
     */
    protected static function clearMailer()
    {
        $oxEMail = oxNew('oxemail');
        $oxEMail->clearAllRecipients();
        $oxEMail->clearReplyTos();
        $oxEMail->clearAttachments();
    }

    /**
     * Get shop language
     *
     * @param  string $iOrderLang language user use when order
     * @return object
     */
    public static function getShopLanguage($iOrderLang)
    {
        $myConfig = self::_getConfig();
        $oShop = oxNew('oxShop');
        $oShop->setLanguage($iOrderLang);
        $oShop->load($myConfig->getShopId());
        return $oShop;
    }

    /**
     * Get subject locale
     */
    /**
     * Get email subject locale
     *
     * @param  string  $status  order status
     * @param  integer $orderId order id
     * @param  object  $oShop   shop object
     * @return string
     */
    public static function setSubjectLocale($status, $orderId, $oShop)
    {
        $myConfig = self::_getConfig();

        $myConfig->setAdminMode(false);
        $statusTranslate = oxRegistry::getLang()->translateString($status);
        $orderTranslate = oxRegistry::getLang()->translateString('GENERAL_TEXT_ORDER');
        $forTranslate = oxRegistry::getLang()->translateString('GENERAL_TEXT_FOR');
        $myConfig->setAdminMode(true);
        $result = $statusTranslate." ".strtolower($forTranslate)." ".$orderTranslate;
        $result .= " #".$orderId." - ".$oShop->oxshops__oxname->value;

        return $result;
    }
}
