<?php
/**
 * Skrill OxOutput
 *
 * The Class for Process Skrill Payment Gateways
 * Copyright (c) Skrill
 *
 * @class   SkrillOxOutput
 * @package Skrill/Classes
 * @located at /models
 * @extend  oxoutput
 */
class SkrillOxOutput extends SkrillOxOutput_parent
{
    /**
     * Function for front-end (normaly HTML) output processing
     * This function is called from index.php
     *
     * @param  string $value         html or string
     * @param  string $viewClassName
     * @return string
     */
    public function process($value, $viewClassName)
    {
        $parentResult = parent::process($value, $viewClassName);

        if ($viewClassName != 'skrill__template') {
            return $parentResult;
        }

        // if shop runs in utf8 mode, skrill needs the template still iso encoded,
        // but skrill will output template as utf8, so the encoding info utf8 should inserted
        // in html header, alls chars not in iso-8859-1 should be html-entity-encoded.
        if (oxRegistry::getConfig()->getConfigParam('iUtfMode')
            && !oxRegistry::getConfig()->getShopConfVar('skrill__use_utf8')) {
            $parentResult = iconv('UTF-8', 'ISO-8859-1//TRANSLIT', $parentResult);
        }

        // remove base tag because the template is shown in skrill-domain context and
        // skrill will insert relative references to resources
        return $this->skrillRemoveBaseTag($parentResult);
    }

    /**
     * Remove base tag
     *
     * @param  string $output output
     * @return string
     */
    protected function skrillRemoveBaseTag($output)
    {
        return preg_replace('%\<base[^>]+\>%', '', $output);
    }
}
